@@ -1,5 +1,5 @@
 package Moment;
-$Moment::VERSION = '1.2.0';
+$Moment::VERSION = '1.2.1';
 # ABSTRACT: class that represents the moment in time
 
 use strict;
@@ -696,7 +696,7 @@ Moment - class that represents the moment in time
 
 =head1 VERSION
 
-version 1.2.0
+version 1.2.1
 
 =head1 SYNOPSIS
 
@@ -819,7 +819,7 @@ Features and limitations of this library:
 
 =item * No dependencies, but perl and its core modules
 
-=item * Plays well with Data::Printer
+=item * Plays well with L<Data::Printer>
 
 =item * Using SemVer for version numbers
 
@@ -1190,12 +1190,11 @@ the same thing:
 
     say $m->plus( hour => 5, minute => 30 )->get_dt();
 
-Q: Why there is no are no numbers to represent week days?
+Q: Why there are no methods to find out the week number?
 
-A: There are several ways to define what is the first day of week. And I
-don't want to choose one possobility, but implementing all possobilities
-makes eveything harder. To make this library as simple as possible, I've
-desided not to implement this feature.
+A: There are several ways to define what is the first week in year. To make
+this library as simple as possible, I've desided not to implement this
+feature.
 
 Q: How to serialize this object and deserialize it?
 
